Title: [188876] trunk/Source/WebInspectorUI
Revision
188876
Author
timo...@apple.com
Date
2015-08-24 12:52:42 -0700 (Mon, 24 Aug 2015)

Log Message

Web Inspector: Change webkitAnimationEnd use, should be animationEnd
https://bugs.webkit.org/show_bug.cgi?id=148385

Reviewed by Joseph Pecoraro.

* UserInterface/Views/DOMTreeElement.js:
(WebInspector.DOMTreeElement.prototype.emphasizeSearchHighlight):
* UserInterface/Views/DashboardContainerView.js:
(WebInspector.DashboardContainerView.prototype._showDashboardView.animationEnded):
(WebInspector.DashboardContainerView.prototype._showDashboardView):
(WebInspector.DashboardContainerView.prototype._hideDashboardView.animationEnded):
(WebInspector.DashboardContainerView.prototype._hideDashboardView):
* UserInterface/Views/DefaultDashboardView.js:
(WebInspector.DefaultDashboardView.prototype._setConsoleItemValue.animationEnded):
(WebInspector.DefaultDashboardView.prototype._setConsoleItemValue):
* UserInterface/Views/TextEditor.js:
(WebInspector.TextEditor.prototype.revealPosition.revealAndHighlightLine):
(WebInspector.TextEditor.prototype.revealPosition):
(WebInspector.TextEditor.prototype._revealSearchResult):

Modified Paths

Diff

Modified: trunk/Source/WebInspectorUI/ChangeLog (188875 => 188876)


--- trunk/Source/WebInspectorUI/ChangeLog	2015-08-24 19:03:28 UTC (rev 188875)
+++ trunk/Source/WebInspectorUI/ChangeLog	2015-08-24 19:52:42 UTC (rev 188876)
@@ -1,3 +1,25 @@
+2015-08-24  Timothy Hatcher  <timo...@apple.com>
+
+        Web Inspector: Change webkitAnimationEnd use, should be animationEnd
+        https://bugs.webkit.org/show_bug.cgi?id=148385
+
+        Reviewed by Joseph Pecoraro.
+
+        * UserInterface/Views/DOMTreeElement.js:
+        (WebInspector.DOMTreeElement.prototype.emphasizeSearchHighlight):
+        * UserInterface/Views/DashboardContainerView.js:
+        (WebInspector.DashboardContainerView.prototype._showDashboardView.animationEnded):
+        (WebInspector.DashboardContainerView.prototype._showDashboardView):
+        (WebInspector.DashboardContainerView.prototype._hideDashboardView.animationEnded):
+        (WebInspector.DashboardContainerView.prototype._hideDashboardView):
+        * UserInterface/Views/DefaultDashboardView.js:
+        (WebInspector.DefaultDashboardView.prototype._setConsoleItemValue.animationEnded):
+        (WebInspector.DefaultDashboardView.prototype._setConsoleItemValue):
+        * UserInterface/Views/TextEditor.js:
+        (WebInspector.TextEditor.prototype.revealPosition.revealAndHighlightLine):
+        (WebInspector.TextEditor.prototype.revealPosition):
+        (WebInspector.TextEditor.prototype._revealSearchResult):
+
 2015-08-24  Nikita Vasilyev  <nvasil...@apple.com>
 
         REGRESSION (r188581): Web Inspector: Console user command isn't visible when it's expected to be

Modified: trunk/Source/WebInspectorUI/UserInterface/Views/DOMTreeElement.js (188875 => 188876)


--- trunk/Source/WebInspectorUI/UserInterface/Views/DOMTreeElement.js	2015-08-24 19:03:28 UTC (rev 188875)
+++ trunk/Source/WebInspectorUI/UserInterface/Views/DOMTreeElement.js	2015-08-24 19:52:42 UTC (rev 188876)
@@ -99,7 +99,7 @@
             this._bouncyHighlightElement = null;
         }
 
-        this._bouncyHighlightElement.addEventListener("webkitAnimationEnd", animationEnded.bind(this));
+        this._bouncyHighlightElement.addEventListener("animationEnd", animationEnded.bind(this));
     }
 
     _updateSearchHighlight(show)

Modified: trunk/Source/WebInspectorUI/UserInterface/Views/DashboardContainerView.js (188875 => 188876)


--- trunk/Source/WebInspectorUI/UserInterface/Views/DashboardContainerView.js	2015-08-24 19:03:28 UTC (rev 188875)
+++ trunk/Source/WebInspectorUI/UserInterface/Views/DashboardContainerView.js	2015-08-24 19:52:42 UTC (rev 188876)
@@ -190,14 +190,14 @@
             if (event.target !== dashboardView.element)
                 return;
 
-            dashboardView.element.removeEventListener("webkitAnimationEnd", animationEnded);
+            dashboardView.element.removeEventListener("animationEnd", animationEnded);
             dashboardView.element.classList.remove(animationClass);
             container._updateAdvanceArrowVisibility();
         }
 
         if (animationClass) {
             dashboardView.element.classList.add(animationClass);
-            dashboardView.element.addEventListener("webkitAnimationEnd", animationEnded);
+            dashboardView.element.addEventListener("animationEnd", animationEnded);
         }
 
         return dashboardView;
@@ -223,7 +223,7 @@
             if (event.target !== dashboardView.element)
                 return;
 
-            dashboardView.element.removeEventListener("webkitAnimationEnd", animationEnded);
+            dashboardView.element.removeEventListener("animationEnd", animationEnded);
             dashboardView.element.classList.remove(animationClass);
             dashboardView.element.classList.remove(WebInspector.DashboardContainerView.VisibleDashboardStyleClassName);
             container._updateAdvanceArrowVisibility();
@@ -234,7 +234,7 @@
 
         if (animationClass) {
             dashboardView.element.classList.add(animationClass);
-            dashboardView.element.addEventListener("webkitAnimationEnd", animationEnded);
+            dashboardView.element.addEventListener("animationEnd", animationEnded);
         } else
             dashboardView.element.classList.remove(WebInspector.DashboardContainerView.VisibleDashboardStyleClassName);
     }

Modified: trunk/Source/WebInspectorUI/UserInterface/Views/DefaultDashboardView.js (188875 => 188876)


--- trunk/Source/WebInspectorUI/UserInterface/Views/DefaultDashboardView.js	2015-08-24 19:03:28 UTC (rev 188875)
+++ trunk/Source/WebInspectorUI/UserInterface/Views/DefaultDashboardView.js	2015-08-24 19:52:42 UTC (rev 188876)
@@ -164,7 +164,7 @@
         {
             if (event.target === container) {
                 container.classList.remove("pulsing");
-                container.removeEventListener("webkitAnimationEnd", animationEnded);
+                container.removeEventListener("animationEnd", animationEnded);
             }
         }
 
@@ -174,7 +174,7 @@
             container.classList.remove("pulsing");
             container.recalculateStyles();
         } else
-            container.addEventListener("webkitAnimationEnd", animationEnded);
+            container.addEventListener("animationEnd", animationEnded);
 
         container.classList.add("pulsing");
     }

Modified: trunk/Source/WebInspectorUI/UserInterface/Views/TextEditor.js (188875 => 188876)


--- trunk/Source/WebInspectorUI/UserInterface/Views/TextEditor.js	2015-08-24 19:03:28 UTC (rev 188875)
+++ trunk/Source/WebInspectorUI/UserInterface/Views/TextEditor.js	2015-08-24 19:52:42 UTC (rev 188876)
@@ -495,8 +495,8 @@
 
             this._codeMirror.addLineClass(lineHandle, "wrap", WebInspector.TextEditor.HighlightedStyleClassName);
 
             // Use a timeout instead of a webkitAnimationEnd event listener because the line element might
             // be removed if the user scrolls during the animation. In that case webkitAnimationEnd isn't
             // fired, and the line would highlight again the next time it scrolls into view.
             setTimeout(removeStyleClass.bind(this), WebInspector.TextEditor.HighlightAnimationDuration);
         }
@@ -960,7 +960,7 @@
         }
 
         // Listen for the end of the animation so we can remove the element.
-        this._bouncyHighlightElement.addEventListener("webkitAnimationEnd", animationEnded.bind(this));
+        this._bouncyHighlightElement.addEventListener("animationEnd", animationEnded.bind(this));
     }
 
     _binarySearchInsertionIndexInSearchResults(object, comparator)
@@ -495,8 +495,8 @@
             this._codeMirror.addLineClass(lineHandle, "wrap", WebInspector.TextEditor.HighlightedStyleClassName);
 
-            // Use a timeout instead of a webkitAnimationEnd event listener because the line element might
-            // be removed if the user scrolls during the animation. In that case webkitAnimationEnd isn't
+            // Use a timeout instead of a animationEnd event listener because the line element might
+            // be removed if the user scrolls during the animation. In that case animationEnd isn't
             // fired, and the line would highlight again the next time it scrolls into view.
             setTimeout(removeStyleClass.bind(this), WebInspector.TextEditor.HighlightAnimationDuration);
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to